import setuptools

setuptools.setup(
	name="asura",
	version="0.0.7",
	author="Simon G.",
	author_email="joe@who.joemama",
	description="A package that I'm gonna use a lot.",
	packages=["asura"],
	python_requires='>=3.9',
)
